
=head1 COPYRIGHT

This extension is Copyright (C) 2007 RedIRIS

It is freely redistributable under the terms of version 2 of the GNU GPL.

=cut

package RT::Authen::Federation;

our $VERSION = '1.2.1';

1;
